summaryrefslogtreecommitdiff
path: root/webtest/response.py
diff options
context:
space:
mode:
authorGeorges Dubus <georges.dubus@compiletoi.net>2013-02-23 15:52:23 +0100
committerGeorges Dubus <georges.dubus@compiletoi.net>2013-02-23 16:17:40 +0100
commit332f10f7614a0524a84406b4c99c164e0999754c (patch)
tree794be4c84621cb60c3bebf54f39271523988143f /webtest/response.py
parentda6a4863cb5159bd378fa87edb22e1e3c6e2e761 (diff)
downloadwebtest-332f10f7614a0524a84406b4c99c164e0999754c.tar.gz
Fixes to the doc, mostly links and typos.
Also added intersphinx (http://sphinx-doc.org/ext/intersphinx.html) to have nice links to the webob doc.
Diffstat (limited to 'webtest/response.py')
-rw-r--r--webtest/response.py18
1 files changed, 10 insertions, 8 deletions
diff --git a/webtest/response.py b/webtest/response.py
index 680bc81..0ec0804 100644
--- a/webtest/response.py
+++ b/webtest/response.py
@@ -23,7 +23,7 @@ import webob
class TestResponse(webob.Response):
"""
Instances of this class are return by ``TestApp``
"""
request = None
@@ -32,8 +32,9 @@ class TestResponse(webob.Response):
@property
def forms(self):
"""
- Returns a dictionary of :class:`~webtest.Form` objects. Indexes are
- both in order (from zero) and by form id (if the form is given an id).
+ Returns a dictionary of :class:`~webtest.forms.Form` objects.
+ Indexes are both in order (from zero) and by form id (if the
+ form is given an id).
"""
if self._forms_indexed is None:
self._parse_forms()
@@ -41,8 +42,8 @@ class TestResponse(webob.Response):
@property
def form(self):
- """Returns a single :class:`~webtest.Form` instance; it is an
- error if there are multiple forms on the page.
+ """Returns a single :class:`~webtest.forms.Form` instance; it
+ is an error if there are multiple forms on the page.
"""
forms_ = self.forms
if not forms_:
@@ -142,7 +143,8 @@ class TestResponse(webob.Response):
def clickbutton(self, description=None, buttonid=None, href=None,
button=None, index=None, verbose=False):
"""
- Like ``.click()``, except looks for link-like buttons.
+ Like :meth:`~webtest.TestResponse.click`, except looks
+ for link-like buttons.
This kind of button should look like
``<button onclick="...location.href='url'...">``.
"""
@@ -251,8 +253,8 @@ class TestResponse(webob.Response):
"""
Go to the (potentially relative) link ``href``, using the
given method (``'get'`` or ``'post'``) and any extra arguments
- you want to pass to the ``app.get()`` or ``app.post()``
- methods.
+ you want to pass to the :meth:`webtest.TestApp.get` or
+ :meth:`webtest.TestApp.post` methods.
All hostnames and schemes will be ignored.
"""
@@ -23,7 +23,7 @@ import webob
class TestResponse(webob.Response):
"""
- Instances of this class are return by ``TestApp``
+ Instances of this class are returned by :class:`~webtest.TestApp`
"""
request = None